@@ -64,8 +64,8 @@ CompressedFile::CompressedFile( ArkWidget *_gui, const QString & _fileName, cons
   m_tempDirectory->setAutoDelete( true );
   m_tmpdir = m_tempDirectory->name();
   initData();
-  verifyCompressUtilityIsAvailable(m_archiver_program);
-  verifyUncompressUtilityIsAvailable(m_unarchiver_program);
+  verifyCompressUtilityIsAvailable( m_archiver_program );
+  verifyUncompressUtilityIsAvailable( m_unarchiver_program );
 
   if (!QFile::exists(_fileName))
   {
@@ -165,9 +165,12 @@ void CompressedFile::open()
   KURL src, target;
   src.setPath( m_filename );
   target.setPath( m_tmpfile );
-  KIO::NetAccess::copy( m_filename, m_tmpfile, m_gui );
 
-  kdDebug(1601) << "Temp file name is " << m_tmpfile << endl;
+  KIO::NetAccess::copy( src, target, m_gui );
+  kdDebug(1601) << "Temp file name is " << target << endl;
+
+  if ( !KIO::NetAccess::exists( target, true, NULL ) )
+    return;
 
   KProcess *kp = m_currentProcess = new KProcess;
   kp->clearArguments();
@@ -275,7 +278,7 @@ void CompressedFile::addFile( const QStringList &urls )
 
   m_tmpfile = file.right(file.length()
 			 - file.findRev("/")-1);
-  m_tmpfile = m_tmpdir + "/" + m_tmpfile;
+  m_tmpfile = m_tmpdir + '/' + m_tmpfile;
 
   kdDebug(1601) << "Temp file name is " << m_tmpfile << endl;
 
