@@ -21,7 +21,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
@@ -49,9 +49,8 @@ class ZipArch : public Arch
     virtual void addDir( const QString &  );
 
     virtual void remove( QStringList * );
-    virtual void unarchFile( QStringList *, const QString & destDir = "",
-                             bool viewFriendly = false );
-
+    virtual void unarchFileInternal();
+    virtual bool passwordRequired();
   private:
     void setHeaders();
 };
