@@ -50,16 +50,6 @@
 	#define PRINT_HEX    "%lX"
 #endif
 
-#define		HEX_SIZE	sizeof(KCALC_LONG)*2
-#define		OCT_SIZE	(int)(sizeof(KCALC_LONG) * 2.75)
-// unsure how to properly deside how many decimal digits we can enter
-// so we'll just go with same as BIN to be safe..
-#define		DEC_SIZE	sizeof(KCALC_LONG)*8
-#define		BIN_SIZE	sizeof(KCALC_LONG)*8
-
-// DSP_SIZE should be == BIN_SIZE as BIN_SIZE is the largest one..
-#define		DSP_SIZE	BIN_SIZE // 25
-
 #define		NUM_STATUS_TEXT 4
 
 /*
@@ -127,7 +117,6 @@ private:
 	int  _button;
 	bool _lit;
 	NumBase _num_base;
-	int _display_size;
 
 	int _precision;
 	int _fixed_precision; // "-1" = no fixed_precision
