@@ -69,7 +69,10 @@ KNumber::KNumber(unsigned long long int num)
 
 KNumber::KNumber(double num)
 {
-  _num = new _knumfloat(num);
+  if ( isinf(num) ) _num = new _knumerror( _knumber::Infinity );
+  else if ( isnan(num) ) _num = new _knumerror( _knumber::UndefinedNumber );
+  else _num = new _knumfloat(num);      
+
 }
 
 KNumber::KNumber(KNumber const & num)
@@ -481,7 +484,7 @@ KNumber const KNumber::power(KNumber const &exp) const
   }
 
   if (exp == Zero) {
-    if (*this > Zero)
+    if (*this != Zero)
       return One;
     else
       return KNumber("nan");
@@ -659,6 +662,10 @@ KNumber::operator unsigned long int(void) const
 
 KNumber::operator unsigned long long int(void) const
 {
+#if SIZEOF_LONG >= 8
+  return static_cast<unsigned long int>(*this);
+#else
+
   KNumber tmp_num1 = this->abs().integerPart();
   unsigned long long int tmp_num2 =  static_cast<unsigned long int>(tmp_num1) +
     (static_cast<unsigned long long int>(
@@ -669,7 +676,8 @@ KNumber::operator unsigned long long int(void) const
     return tmp_num2;
   else
     return static_cast<unsigned long long int> (- static_cast<signed long long int>(tmp_num2));
-  
+
+#endif  
 }
 
 KNumber::operator double(void) const
