@@ -15,9 +15,10 @@
  ***************************************************************************/
 
 
-#ifndef KCOLTEXTEXPORT_H
-#define KCOLTEXTEXPORT_H
+#ifndef KHE_KCOLTEXTEXPORT_H
+#define KHE_KCOLTEXTEXPORT_H
 
+class QString;
 
 namespace KHE
 {
@@ -28,8 +29,8 @@ namespace KHE
 class KColTextExport
 {
   public: // API
-    virtual void printFirstLine( char **T, int Line ) const = 0;
-    virtual void printNextLine( char **T ) const = 0;
+    virtual void printFirstLine( QString &T, int Line ) const = 0;
+    virtual void printNextLine( QString &T ) const = 0;
     /** tells how much chars per line are needed */
     virtual int charsPerLine() const = 0;
 };
