@@ -50,6 +50,7 @@ class KSection : public KRange<int>
     bool operator==( const KSection &S ) const;
 
   public:
+    void setByWidth( int S, int Width );
     /** sets the first index of the section's range one behind the other's end
       * If one of both is invalid the behaviour is undefined
       */
@@ -58,10 +59,22 @@ class KSection : public KRange<int>
       * If one of both is invalid or the other' start is 0 the behaviour is undefined
       */
     void setEndBefore( KSection S );
+    /** sets the first index of the section's range to be width-1 before the end
+     * If the section is invalid the behaviour is undefined
+     */
+    void setStartByWidth( int Width );
     /** sets the last index of the section's range to be width-1 behind the start
       * If the section is invalid the behaviour is undefined
       */
     void setEndByWidth( int Width );
+    /** moves the range defined by a new start.
+     * If the range is invalid the behaviour is undefined
+     */
+    void moveToStart( int S );
+    /** moves the range defined by a new start.
+     * If the range is invalid the behaviour is undefined
+     */
+    void moveToEnd( int E );
 
   public:
     /**
@@ -82,10 +95,14 @@ inline KSection &KSection::operator=( const KSection &S ) { KRange<int>::operato
 
 inline int KSection::width() const { return isValid() ? end()-start()+1 : 0; }
 
+inline void KSection::setByWidth( int S, int Width )  { setStart( S ); setEnd( S+Width-1 ); }
+inline void KSection::setStartByWidth( int Width )  { setStart( end()-Width+1 ); }
 inline void KSection::setEndByWidth( int Width )    { setEnd( start()+Width-1 ); }
 inline void KSection::setStartBehind( KSection S )  { setStart( S.end()+1 ); }
 inline void KSection::setEndBefore( KSection S )    { setEnd( S.start()-1 ); }
 
+inline void KSection::moveToStart( int S ) { setEnd( S+width()-1 ); setStart( S ); }
+inline void KSection::moveToEnd( int E )   { setStart( E-width()+1 ); setEnd( E ); }
 }
 
 #endif
