@@ -134,9 +134,9 @@ KJotsMain::KJotsMain(const char* name)
             SLOT(writeBookToHTML()), actionCollection(), "save_book_to_html");
     actions[ACTION_BOOK2HTML]->plug(exportBookMenu->popupMenu());
 
-    actions[ACTION_DELETE_PAGE] = new KAction(i18n("&Delete Page"), "editdelete", 0, this,
+    actions[ACTION_DELETE_PAGE] = new KAction(i18n("&Delete Page"), "editdelete", CTRL + Key_Delete, this,
             SLOT(deleteEntry()), actionCollection(), "del_page");
-    actions[ACTION_DELETE_BOOK] = new KAction(i18n("Delete Boo&k"), "editdelete", 0, this,
+    actions[ACTION_DELETE_BOOK] = new KAction(i18n("Delete Boo&k"), "editdelete", CTRL + SHIFT + Key_Delete, this,
             SLOT(deleteBook()), actionCollection(), "del_folder");
 
     actions[ACTION_MANUAL_SAVE] = new KAction(i18n("Manual Save"), 0, KStdAccel::save(),
@@ -421,6 +421,24 @@ void KJotsMain::slotReplace()
 
 void KJotsMain::updateConfiguration()
 {
+    static int encoding = -1;
+
+    //Keep track of the encoding setting. If the user changes it, we
+    //need to mark all books dirty so they are saved correctly.
+    if ( encoding == -1 ) {
+        encoding = KJotsSettings::unicode();
+    } else {
+        if ( (int)encoding != KJotsSettings::unicode() ) {
+            KJotsBook *book = dynamic_cast<KJotsBook*>(subjectList->firstChild());
+            while (book) {
+                book->setDirty(true);
+                book = dynamic_cast<KJotsBook*>(book->nextSibling());
+            }
+
+            encoding = (int)KJotsSettings::unicode();
+        }
+    }
+
     me_text->setFont(KJotsSettings::font());
     if (KJotsSettings::autoSave())
         m_autosaveTimer->changeInterval(KJotsSettings::autoSaveInterval()*1000*60);
