@@ -211,7 +211,13 @@ void BatteryConfig::save()
 
 void BatteryConfig::load()
 {
-       	config->setGroup("BatteryDefault");
+	load( false );
+}
+
+void BatteryConfig::load(bool useDefaults)
+{
+	     config->setReadDefaults( useDefaults );
+        config->setGroup("BatteryDefault");
 
         poll_time = config->readNumEntry("Poll", 20);
         enablemonitor = config->readBoolEntry("Enable", true);
@@ -233,34 +239,13 @@ void BatteryConfig::load()
         }
         battery_pm = SmallIcon(nochargebattery, 20, KIcon::DefaultState, instance);
         battery_nopm = SmallIcon(nobattery, 20, KIcon::DefaultState, instance);
-        changed(false);
+        emit changed(useDefaults);
 	BatteryStateUpdate();
 }
 
 void BatteryConfig::defaults()
 {
-        poll_time = 20;
-        enablemonitor = true;
-	useblanksaver = false;
-	notifyme = false;
-
-        nobattery = "laptop_nobattery";
-        nochargebattery = "laptop_nocharge";
-        chargebattery = "laptop_charge";
-
-        runMonitor->setChecked(enablemonitor);
-        notifyMe->setChecked(notifyme);
-	blankSaver->setChecked(useblanksaver);
-        if (apm) {
-                editPoll->setValue(poll_time);
-                buttonNoCharge->setIcon(nochargebattery);
-                buttonCharge->setIcon(chargebattery);
-                buttonNoBattery->setIcon(nobattery);
-        }
-        battery_pm = SmallIcon(nochargebattery, 20, KIcon::DefaultState, instance);
-        battery_nopm = SmallIcon(nobattery, 20, KIcon::DefaultState, instance);
-        changed(true);
-	BatteryStateUpdate();
+	load( true );
 }
 
 
