@@ -1,7 +1,7 @@
 /*
  * portable.cpp
  *
- * $Id: portable.cpp 490596 2005-12-22 13:05:45Z scripty $
+ * $Id: portable.cpp 540996 2006-05-15 09:55:42Z mueller $
  *
  * Copyright (c) 1999 Paul Campbell <paul@taniwha.com>
  *
@@ -138,17 +138,15 @@ apm_read(apm_info *ap)
 	   	&ap->battery_percentage,
 	   	&ap->battery_time,
 	   	tmp2);
-	if (s < 9)
+        fclose(f);
+	if (s < 9) 
 		return(1);	
-	if (version[0] == 'B') {
-		fclose(f);
+	if (version[0] == 'B')
 		return(2);
-	}
    	if (ap->battery_percentage > 100) 
 		ap->battery_percentage = -1;
 	if (strcmp(tmp2, "sec") == 0)
 		ap->battery_time /= 60;
-   	fclose(f);
 	return(0);
 }
 
@@ -578,7 +576,8 @@ has_software_suspend(int type)
 		known = last_seed;
 		available = 0;
 		present = (((::access("/proc/sys/kernel/swsusp", F_OK) == 0) ||
-                            (::access("/proc/software_suspend", F_OK) == 0)) &&
+                            (::access("/proc/software_suspend", F_OK) == 0) ||
+                            (::access("/proc/suspend2", F_OK) == 0)) &&
 		           ::access("/usr/sbin/hibernate", F_OK) == 0);
 		if (present) {
 			if (::getuid() == 0) {	// running as root
