@@ -130,7 +130,7 @@ bool DellI8kMonitor::retrieveVolume()
 {
     bool kmix_error = false;
 
-    DCOPReply reply = kmixClient->call( "volume", 0 );
+    DCOPReply reply = kmixClient->call( "masterVolume");
 
     if( reply.isValid() )
     {
@@ -147,12 +147,12 @@ bool DellI8kMonitor::retrieveVolume()
         if( kapp->startServiceByDesktopName( "kmix" ) == 0 )            // trying to start kmix
         {
             // trying again
-            reply = kmixClient->call( "volume", 0 );
+            reply = kmixClient->call( "masterVolume");
             if( reply.isValid() )
             {
                 m_volume = reply;
                 kmix_error = false;
-                kmixWindow->send( "minimize" );
+                kmixWindow->send( "hide" );
             }
         }
     }
@@ -186,7 +186,7 @@ void DellI8kMonitor::setVolume(int volume)
         m_volume = volume;
     }
 
-    kmixClient->send("setVolume", 0, m_volume);
+    kmixClient->send("setMasterVolume", m_volume);
 
     m_progress = m_volume;
 }
@@ -212,12 +212,12 @@ bool DellI8kMonitor::retrieveMute()
         if( kapp->startServiceByDesktopName( "kmix" ) == 0 )            // trying to start kmix
         {
             // trying again
-            reply = kmixClient->call( "volume", 0 );
+            reply = kmixClient->call( "masterVolume" );
             if( reply.isValid() )
             {
                 m_volume = reply;
                 kmix_error = false;
-                kmixWindow->send( "minimize" );
+                kmixWindow->send( "hide" );
             }
         }
     }
