@@ -92,7 +92,7 @@ bool GenericMonitor::retrieveVolume()
 {
 	bool kmix_error = false;
 
-	DCOPReply reply = kmixClient->call("volume", 0);
+	DCOPReply reply = kmixClient->call("masterVolume");
 	if (reply.isValid())
 		m_volume = reply;
 	else
@@ -104,7 +104,7 @@ bool GenericMonitor::retrieveVolume()
 		if (kapp->startServiceByDesktopName("kmix")==0) // trying to start kmix
 		{
 			// trying again
-			reply = kmixClient->call("volume", 0);
+			reply = kmixClient->call("masterVolume");
 			if (reply.isValid()) 
 			{
 				m_volume = reply;
@@ -163,7 +163,7 @@ void GenericMonitor::displayVolume()
 
 	// If we got this far, the DCOP communication with kmix works,
   // so we don't have to test the result.
-	kmixClient->send("setVolume", 0, m_volume);
+	kmixClient->send("setMasterVolume", m_volume);
 
 	// if mute then unmute
 	if (m_mute)
