@@ -11,7 +11,7 @@
          This code may be linked against any version of the Qt toolkit
          from Troll Tech, Norway. $
 
-   $Id: kvaio.cpp 503951 2006-01-30 20:57:03Z mueller $
+   $Id: kvaio.cpp 583838 2006-09-13 16:42:32Z helio $
 
    * Portions of this code are
    * (C) 2001-2002 Stelian Pop <stelian@popies.net> and
@@ -455,7 +455,7 @@ void KVaio::displayVolume()
 	showProgressMsg(i18n("Volume"), m_volume);
         // If we got this far, the DCOP communication with kmix works,
 	// so we don't have to test the result.
-        kmixClient->send("setVolume", 0, m_volume);
+        kmixClient->send("setMasterVolume", m_volume);
 
         // if mute then unmute
         if (m_mute)
@@ -469,7 +469,7 @@ void KVaio::displayVolume()
 bool KVaio::retrieveVolume() {
        bool kmix_error = false;
 
-        DCOPReply reply = kmixClient->call("volume", 0);
+        DCOPReply reply = kmixClient->call("masterVolume");
         if (reply.isValid())
                 m_volume = reply;
         else
@@ -482,12 +482,12 @@ bool KVaio::retrieveVolume() {
                 if (kapp->startServiceByDesktopName("kmix")==0) // trying to start kmix
                 {
                         // trying again
-                        reply = kmixClient->call("volume", 0);
+                        reply = kmixClient->call("masterVolume");
                         if (reply.isValid())
                         {
                                 m_volume = reply;
                                 kmix_error = false;
-                                kmixWindow->send("minimize");
+                                kmixWindow->send("hide");
                         }
                 }
         }
@@ -554,11 +554,11 @@ bool KVaio::retrieveMute()
                         {
                                 m_mute = reply;
                                 kmix_error = false;
-                                kmixWindow->send("minimize");
+                                kmixWindow->send("hide");
                         }
                 }       else
                 {
-                        kmixWindow->send("minimize");
+                        kmixWindow->send("hide");
                         kmix_error = true;
                 }
         }
