@@ -453,7 +453,7 @@ void ThinkPadMonitor::reconfigure(KConfig* config) {
 bool ThinkPadMonitor::retrieveVolume() {
 	bool kmix_error = false;
 
-	DCOPReply reply = kmixClient->call("volume", 0);
+	DCOPReply reply = kmixClient->call("masterVolume");
 	if (reply.isValid())  {
 		m_volume = reply;
 	} else {
@@ -463,11 +463,11 @@ bool ThinkPadMonitor::retrieveVolume() {
 	if (kmix_error) { // maybe the error occurred because kmix wasn't running
 		if (kapp->startServiceByDesktopName("kmix")==0) { // trying to start kmix
 			// trying again
-			reply = kmixClient->call("volume", 0);
+			reply = kmixClient->call("masterVolume");
 			if (reply.isValid())  {
 				m_volume = reply;
 				kmix_error = false;
-				kmixWindow->send("minimize");
+				kmixWindow->send("hide");
 			}
 		}
 	}
@@ -492,7 +492,7 @@ void ThinkPadMonitor::setVolume(int volume) {
 	} else {
 		m_volume = volume;
 	}
-	kmixClient->send("setVolume", 0, m_volume);
+	kmixClient->send("setMasterVolume", m_volume);
 
 	//write back to nvram but only if volume steps is not default
 	if (m_volumeStep != defaultVolumeStep) {
