@@ -1741,7 +1741,7 @@ void karamba::addMenuConfigOption(QString key, QString name)
   kpop -> setItemEnabled(THEMECONF, true);
 
   SignalBridge* action = new SignalBridge(this, key, menuAccColl);
-  KToggleAction* confItem = new KToggleAction (name.ascii(), KShortcut::null(),
+  KToggleAction* confItem = new KToggleAction (name, KShortcut::null(),
                                                action, SLOT(receive()),
                                                menuAccColl, key.ascii());
   confItem -> setName(key.ascii());
@@ -1912,7 +1912,7 @@ void karamba::dropEvent(QDropEvent* event)
     if (pythonIface && pythonIface->isExtensionLoaded())
     {
       const QPoint &p = event->pos();
-      pythonIface->itemDropped(this, text.ascii(), p.x(), p.y());
+      pythonIface->itemDropped(this, text, p.x(), p.y());
     }
   }
 }
